==> reinvent_chemistry-0.0.33.tar.gz: reinvent_chemistry-0.0.33/unittest_reinvent/library_design/test_failing_reactions_enumerator.py <==
import unittest

from reinvent_chemistry import Conversions
from reinvent_chemistry.library_design import FailingReactionsEnumerator
from reinvent_chemistry.library_design.fragment_reactions import FragmentReactions
from unittest_reinvent.library_design.fixtures import FRAGMENT_REACTIONS, FRAGMENT_REACTION_SUZUKI


class TestFailingReactionsEnumerator(unittest.TestCase):

    def setUp(self):
        self.chemistry = Conversions()
        self.reactions = FragmentReactions()
        self._suzuki_reaction_dto_list = self.reactions.create_reactions_from_smirks(FRAGMENT_REACTIONS)
        self.suzuki_positive_smile = "COc1c(-c2cnn(C(NCC)CCCCCC3CCC(N(C)C(C)=O)CC3)c2)cnc2ccc(-c3ccncn3)nc12"
        self.suzuki_positive_molecule = self.chemistry.smile_to_mol(self.suzuki_positive_smile)

        self._slice_enumerator = FailingReactionsEnumerator(self._suzuki_reaction_dto_list)

    def test_failed_slicing_1(self):
        result = self._slice_enumerator.enumerate(self.suzuki_positive_molecule, 1)

        self.assertEqual(1, len(result))
        self.assertEqual(result[0].reaction_smirks, '[#6;!$([#6]=*);!$([#6]~[O,N,S]);$([#6]~[#6]):1][c:2]>>[*:2][*].[*:1][*]')

    def test_failed_slicing_2(self):
        result = self._slice_enumerator.enumerate(self.suzuki_positive_molecule, 3)

        self.assertEqual(2, len(result))
        self.assertEqual(result[0].reaction_smirks, '[#6;!$([#6]=*);!$([#6]~[O,N,S]);$([#6]~[#6]):1][c:2]>>[*:2][*].[*:1][*]')


class TestNonFailingReactionsEnumerator(unittest.TestCase):

    def setUp(self):
        self.chemistry = Conversions()
        self.reactions = FragmentReactions()
        self._suzuki_reaction_dto_list = self.reactions.create_reactions_from_smirks(FRAGMENT_REACTION_SUZUKI)
        self.suzuki_positive_smile = "COc1c(-c2cnn(C(NCC)CCCCCC3CCC(N(C)C(C)=O)CC3)c2)cnc2ccc(-c3ccncn3)nc12"
        self.suzuki_positive_molecule = self.chemistry.smile_to_mol(self.suzuki_positive_smile)

        self._slice_enumerator = FailingReactionsEnumerator(self._suzuki_reaction_dto_list)

    def test_non_failed_slicing_1(self):
        result = self._slice_enumerator.enumerate(self.suzuki_positive_molecule, 1)

        self.assertEqual(0, len(result))

==> reinvent_chemistry-0.0.39.tar.gz: reinvent_chemistry-0.0.39/unittest_reinvent/library_design/test_failing_reactions_enumerator.py <==
import unittest

from reinvent_chemistry import Conversions
from reinvent_chemistry.library_design import FailingReactionsEnumerator
from reinvent_chemistry.library_design.fragment_reactions import FragmentReactions
from unittest_reinvent.fixtures.test_data import CELECOXIB
from unittest_reinvent.library_design.fixtures import FRAGMENT_REACTIONS, FRAGMENT_REACTION_SUZUKI


class TestFailingReactionsEnumerator(unittest.TestCase):

    def setUp(self):
        self.chemistry = Conversions()
        self.reactions = FragmentReactions()
        self._suzuki_reaction_dto_list = self.reactions.create_reactions_from_smirks(FRAGMENT_REACTIONS)
        self.suzuki_positive_smile = CELECOXIB
        self.suzuki_positive_molecule = self.chemistry.smile_to_mol(self.suzuki_positive_smile)

        self._slice_enumerator = FailingReactionsEnumerator(self._suzuki_reaction_dto_list)

    def test_failed_slicing_1(self):
        result = self._slice_enumerator.enumerate(self.suzuki_positive_molecule, 1)

        self.assertEqual(1, len(result))
        self.assertEqual(result[0].reaction_smirks, '[#6;!$([#6]=*);!$([#6]~[O,N,S]);$([#6]~[#6]):1][c:2]>>[*:2][*].[*:1][*]')

    def test_failed_slicing_2(self):
        result = self._slice_enumerator.enumerate(self.suzuki_positive_molecule, 3)

        self.assertEqual(2, len(result))
        self.assertEqual(result[0].reaction_smirks, '[#6;!$([#6]=*);!$([#6]~[O,N,S]);$([#6]~[#6]):1][c:2]>>[*:2][*].[*:1][*]')


class TestNonFailingReactionsEnumerator(unittest.TestCase):

    def setUp(self):
        self.chemistry = Conversions()
        self.reactions = FragmentReactions()
        self._suzuki_reaction_dto_list = self.reactions.create_reactions_from_smirks(FRAGMENT_REACTION_SUZUKI)
        self.suzuki_positive_smile = CELECOXIB
        self.suzuki_positive_molecule = self.chemistry.smile_to_mol(self.suzuki_positive_smile)

        self._slice_enumerator = FailingReactionsEnumerator(self._suzuki_reaction_dto_list)

    def test_non_failed_slicing_1(self):
        result = self._slice_enumerator.enumerate(self.suzuki_positive_molecule, 1)

        self.assertEqual(0, len(result))
